@@ -644,7 +644,7 @@ async fn test_fundings() {
 /// Test successful request to get user_trades
 #[tokio::test]
 async fn test_user_trades() {
-    let _mock = mock("GET", "/v3/user_trades/")
+    let mut _mock = mock("GET", "/v3/user_trades/")
         .match_query(Matcher::UrlEncoded("book".into(), "btc_mxn".into()))
         .with_status(200)
         .with_body(
@@ -661,7 +661,37 @@ async fn test_user_trades() {
                 "tid": 51756,
                 "oid": "g81d3y1ywri0yg8m",
                 "side": "sell",
-                "make_side": "sell"
+                "maker_side": "sell"
+            }]
+        }"#,
+        )
+        .create();
+    let bitso = Bitso::default()
+        .prefix(mockito::server_url().as_str())
+        .client_credentials_manager(CLIENT_CREDENTIAL.lock().unwrap().clone())
+        .build();
+    let mut result = bitso
+        .get_user_trades(Some("btc_mxn"), None, None, None)
+        .await;
+    assert!(result.is_ok());
+    println!("{:?}", result);
+    _mock = mock("GET", "/v3/user_trades/")
+        .with_status(200)
+        .with_body(
+            r#"{
+            "success": true,
+            "payload": [{
+                "book": "btc_mxn",
+                "major": "-0.25232073",
+                "created_at": "2016-04-08T17:52:31.000+00:00",
+                "minor": "1013.540958479115",
+                "fees_amount": "-10.237787459385",
+                "fees_currency": "mxn",
+                "price": "4057.45",
+                "tid": 51756,
+                "oid": "g81d3y1ywri0yg8m",
+                "side": "sell",
+                "maker_side": "sell"
             }, {
                 "book": "eth_mxn",
                 "major": "4.86859395",
@@ -673,16 +703,12 @@ async fn test_user_trades() {
                 "tid": 51757,
                 "oid": "19vaqiv72drbphig",
                 "side": "buy",
-                "make_side": "sell"
+                "maker_side": "sell"
             }]
         }"#,
         )
         .create();
-    let bitso = Bitso::default()
-        .prefix(mockito::server_url().as_str())
-        .client_credentials_manager(CLIENT_CREDENTIAL.lock().unwrap().clone())
-        .build();
-    let result = bitso.get_user_trades("btc_mxn", None, None, None).await;
+    result = bitso.get_user_trades(None, None, None, None).await;
     assert!(result.is_ok());
     println!("{:?}", result);
 }
@@ -707,7 +733,7 @@ async fn test_order_trades() {
                     "oid": "Jvqrschkgdkc1go3",
                     "origin_id": "origin_id1",
                     "side": "sell",
-                    "make_side": "sell"
+                    "maker_side": "sell"
                 },
                 {
                     "book": "btc_mxn",
@@ -721,7 +747,7 @@ async fn test_order_trades() {
                     "oid": "Jvqrschkgdkc1go3",
                     "origin_id": "origin_id1",
                     "side": "sell",
-                    "make_side": "sell"
+                    "maker_side": "sell"
                 }
             ]
         }"#,
@@ -760,7 +786,7 @@ async fn test_order_trades_origin_id() {
                     "oid": "Jvqrschkgdkc1go3",
                     "origin_id": "origin_id1",
                     "side": "sell",
-                    "make_side": "sell"
+                    "maker_side": "sell"
                 }]
         }"#,
         )
@@ -777,76 +803,12 @@ async fn test_order_trades_origin_id() {
 /// Test successful request to get open_orders
 #[tokio::test]
 async fn test_open_orders() {
-    let _mock = mock("GET", "/v3/open_orders")
+    let mut _mock = mock("GET", "/v3/open_orders")
         .with_status(200)
-        .match_query(Matcher::AllOf(vec![Matcher::UrlEncoded(
-            "book".into(),
-            "btc_mxn".into(),
-        )]))
-        .with_body(
-            r#"{
-            "success": true,
-            "payload": [{
-                "book": "btc_mxn",
-                "original_amount": "0.01000000",
-                "unfilled_amount": "0.00500000",
-                "original_value": "56.0",
-                "created_at": "2016-04-08T17:52:31.000+00:00",
-                "updated_at": "2016-04-08T17:52:51.000+00:00",
-                "price": "5600.00",
-                "oid": "543cr2v32a1h68443",
-                "origin_id": "origin_id1",
-                "side": "buy",
-                "status": "partial-fill",
-                "type": "limit"
-            }, {
-                "book": "btc_mxn",
-                "original_amount": "0.12680000",
-                "unfilled_amount": "0.12680000",
-                "original_value": "507.2",
-                "created_at": "2016-04-08T17:52:31.000+00:00",
-                "updated_at": "2016-04-08T17:52:41.000+00:00",
-                "price": "4000.00",
-                "oid": "qlbga6b600n3xta7",
-                "side": "sell",
-                "status": "open",
-                "type": "limit"
-            }, {
-                "book": "btc_mxn",
-                "original_amount": "1.12560000",
-                "unfilled_amount": "1.12560000",
-                "original_value": "6892.66788",
-                "created_at": "2016-04-08T17:52:31.000+00:00",
-                "updated_at": "2016-04-08T17:52:41.000+00:00",
-                "price": "6123.55",
-                "oid": "d71e3xy2lowndkfm",
-                "side": "sell",
-                "status": "open",
-                "type": "limit"
-            }]
-        }"#,
-        )
-        .create();
-    let bitso = Bitso::default()
-        .prefix(mockito::server_url().as_str())
-        .client_credentials_manager(CLIENT_CREDENTIAL.lock().unwrap().clone())
-        .build();
-    let result = bitso.get_open_orders(Some("btc_mxn"), None).await;
-    assert!(result.is_ok());
-    println!("{:?}", result);
-}
-
-/// Test successful request to get open_orders with optional params
-#[tokio::test]
-async fn test_open_orders_optional_params() {
-    let _mock = mock("GET", "/v3/open_orders")
         .match_query(Matcher::AllOf(vec![
             Matcher::UrlEncoded("book".into(), "btc_mxn".into()),
-            Matcher::UrlEncoded("marker".into(), "51755".into()),
-            Matcher::UrlEncoded("sort".into(), "asc".into()),
-            Matcher::UrlEncoded("limit".into(), "1".into()),
+            Matcher::UrlEncoded("currency".into(), "mxn".into()),
         ]))
-        .with_status(200)
         .with_body(
             r#"{
             "success": true,
@@ -861,7 +823,7 @@ async fn test_open_orders_optional_params() {
                 "oid": "543cr2v32a1h68443",
                 "origin_id": "origin_id1",
                 "side": "buy",
-                "status": "partial-fill",
+                "status": "partially filled",
                 "type": "limit"
             }, {
                 "book": "btc_mxn",
@@ -895,16 +857,40 @@ async fn test_open_orders_optional_params() {
         .prefix(mockito::server_url().as_str())
         .client_credentials_manager(CLIENT_CREDENTIAL.lock().unwrap().clone())
         .build();
-    let optional_params = OptionalParams {
-        marker: Some(&51755),
-        sort: Some("asc"),
-        limit: Some(&1),
-    };
-    let result = bitso
-        .get_open_orders(Some("btc_mxn"), Some(optional_params))
+    let mut result = bitso
+        .get_open_orders(Some("btc_mxn"), Some("mxn"), None)
         .await;
-    println!("{:?}", result);
     assert!(result.is_ok());
+    println!("{:?}", result);
+    _mock = mock("GET", "/v3/open_orders")
+        .with_status(200)
+        .match_query(Matcher::AllOf(vec![
+            Matcher::UrlEncoded("book".into(), "btc_mxn".into()),
+            Matcher::UrlEncoded("limit".into(), "1".into()),
+        ]))
+        .with_body(
+            r#"{
+            "success": true,
+            "payload": [{
+                "book": "btc_mxn",
+                "original_amount": "0.01000000",
+                "unfilled_amount": "0.00500000",
+                "original_value": "56.0",
+                "created_at": "2016-04-08T17:52:31.000+00:00",
+                "updated_at": "2016-04-08T17:52:51.000+00:00",
+                "price": "5600.00",
+                "oid": "543cr2v32a1h68443",
+                "origin_id": "origin_id1",
+                "side": "buy",
+                "status": "partially filled",
+                "type": "limit"
+            }]
+        }"#,
+        )
+        .create();
+    result = bitso.get_open_orders(Some("btc_mxn"), None, Some(&1)).await;
+    assert!(result.is_ok());
+    println!("{:?}", result);
 }
 
 /// Test successful request to get lookup_orders with optional params
@@ -929,7 +915,7 @@ async fn test_lookup_orders_with_optional_params() {
                 "price": "5600.00",
                 "oid": "543cr2v32a1h6844",
                 "side": "buy",
-                "status": "partial-fill",
+                "status": "partially filled",
                 "type": "limit"
             }, {
                 "book": "btc_mxn",
@@ -980,7 +966,7 @@ async fn test_lookup_orders() {
                 "price": "5600.00",
                 "oid": "543cr2v32a1h6844",
                 "side": "buy",
-                "status": "partial-fill",
+                "status": "partially filled",
                 "type": "limit"
             }]
         }"#,
